@@ -8,7 +8,7 @@ use Devel::Cover::DB;
 use Devel::Cover::Html_Common "launch";
 use Devel::Cover::Truth_Table;
 
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.09'; # VERSION
 our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 #-------------------------------------------------------------------------------
@@ -451,11 +451,19 @@ sub escape_HTML {
 
     $text = CGI::escapeHTML($text);
 
-    # IE doesn't honor "white-space: pre" CSS
-    $text =~ s/^(\t+)/' ' x (8 * length $1)/se;
-    $text =~ s/^(\s+)/'&nbsp;' x length $1/se;
+    # Do not allow FF in text
+    $text =~ tr/\x0c//d;
 
-    return $text;
+    # IE doesn't honor "white-space: pre" CSS
+    my @text = split m/\n/ => $text;
+    for (@text) {
+	# Expand all tabs to spaces
+	1 while s/\t+/' ' x (length($&) * 8 - length($`) % 8)/e;
+	# make multiple spaces be multiple spaces
+	s/(  +)/'&nbsp;' x length $1/ge;
+    }
+
+    return join "\n" => @text;
 }
 
 #-------------------------------------------------------------------------------
@@ -751,7 +759,7 @@ Devel::Cover::Report::Html_minimal - HTML backend for Devel::Cover
 
 =head1 VERSION
 
-version 1.07
+version 1.09
 
 =head1 SYNOPSIS
 
@@ -809,7 +817,7 @@ Devel::Cover
 
 =head1 LICENCE
 
-Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2014, Paul Johnson (paul@pjcj.net)
 
 This software is free. It is licensed under the same terms as Perl itself.
 
