@@ -1,4 +1,4 @@
-# Copyright 2002-2013, Paul Johnson (paul@pjcj.net)
+# Copyright 2002-2014, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Test;
 use strict;
 use warnings;
 
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 use Carp;
 
@@ -53,6 +53,13 @@ sub new
     $self->get_params
 }
 
+
+sub set_test {
+    my $self = shift;
+    my ($test) = @_;
+    $self->{test} = $test;
+}
+
 sub shell_quote
 {
     my ($item) = @_;
@@ -218,14 +225,23 @@ sub run_test
     }
 
     my $version = int(($] - 5) * 1000 + 0.5);
-    if ($version % 2 && $version < 16)
+    if ($version % 2 && $version < 18)
     {
         Test::plan tests => 1;
         Test::skip("Perl version $] is an obsolete development version", 1);
         return;
     }
 
+    if ($] > 5.019001 && $] < 5.019004)
+    {
+        Test::plan tests => 1;
+        Test::skip("Perl version $] contains a bug which causes this test " .
+                   "to fail", 1);
+        return;
+    }
+
     my ($base, $v) = $self->cover_gold;
+    # print STDERR "[$base,$v]\n";
     return 1 unless $v;  # assume we are generating the golden results
     my $gold = "$base.$v";
 
@@ -426,7 +442,7 @@ Devel::Cover::Test - Internal module for testing
 
 =head1 VERSION
 
-version 1.07
+version 1.09
 
 =head1 METHODS
 
@@ -525,7 +541,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2014, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
